
//%include "wx/wx.h"
%include "ghostscript.h"
%include "gswxlua.h"

// %class wxGsThread;
// %class wxGsImage;
// %class wxGsVisualTracer;

%define e_unknownerror    e_unknownerror
%define e_interrupt       e_interrupt   
%define e_Fatal           e_Fatal       
%define e_Quit 	          e_Quit        
%define e_InterpreterExit e_InterpreterExit
%define e_NeedInput       e_NeedInput   
%define e_Info            e_Info


// The Ghostscript DLL class
// -------------------------
%class wxGsDll, wxObject
    wxGsDll(wxString GsDllLocation = wxEmptyString, wxString GsLibLocation = wxEmptyString, wxString GsFontsLocation = wxEmptyString);
//    ~wxGsDll();

    bool isOK();
    double GetVersion();
//  PSt: blocked by choice!!!!    
//    void SetVisualTracer(wxGsVisualTracer& vd);

//    friend class wxGhostscript;
//    friend class wxGsModule;

%endclass

// Ghostscript instance class
// --------------------------

// Note: currently only one instance can exist at any one time

%enum wxGhostscript::ImageType
  none
  colour
  greyscale
  separations
%endenum

%class wxGhostscript, wxObject

//    friend class wxGsThread;

    wxGhostscript();
    wxGhostscript(wxGsDll *gsdll, const wxArrayString& argarray, wxGhostscript::ImageType imagetype = wxGhostscript::none);
//    virtual ~wxGhostscript();

    bool Create(wxGsDll *gsdll, const wxArrayString& argarray, wxGhostscript::ImageType imagetype = wxGhostscript::none);

    int GetExitCode();

    bool RunString(const wxString& psdata);

    bool RunFile(const wxFileName& fname);
    bool RunFile(const wxString& fname);

    bool isOK();
    bool isReady();
    bool isSuspended();
    bool Suspend();
    bool Resume();
    bool Terminate(int errorcode);

    // Callbacks implemented as virtual functions
    wxString *OnStdin();
    void OnStdout(wxString text);
    void OnStderr(wxString text);
    int OnPoll();
    int OnDisplayOpen(wxGsImage& image);
    int OnDisplayPreClose(wxGsImage& image);
    int OnDisplayClose(wxGsImage& image);
    int OnDisplayPreSize(wxGsImage& image);
    int OnDisplaySize(wxGsImage& image);
    int OnDisplaySync(wxGsImage& image);
    int OnDisplayPage(wxGsImage& image, int copies, bool flush);
    int OnDisplayUpdate(wxGsImage& image, wxRect region);

%endclass

%class wxLuaGhostscript, wxGhostscript

    wxLuaGhostscript();
    wxLuaGhostscript(wxGsDll *gsdll, const wxArrayString& argarray,wxGhostscript::ImageType imagetype = wxGhostscript::colour);
//    virtual ~wxLuaGhostscript();

    // Callbacks implemented as virtual functions
    //virtual wxString *OnStdin();
    //virtual void OnStdout(wxString text);
    //virtual void OnStderr(wxString text);
    //virtual int OnPoll();
    //virtual int OnDisplayOpen(wxGsImage& image);
    //virtual int OnDisplayPreClose(wxGsImage& image);
    //virtual int OnDisplayClose(wxGsImage& image);
    //virtual int OnDisplayPreSize(wxGsImage& image);
    //virtual int OnDisplaySize(wxGsImage& image);
    //virtual int OnDisplaySync(wxGsImage& image);
    //virtual int OnDisplayPage(wxGsImage& image, int copies, bool flush);
    //virtual int OnDisplayUpdate(wxGsImage& image, wxRect region);

%endclass

// The thread that Ghostscript runs in
// -----------------------------------

//%class wxGsThread, wxThread
//    friend class wxGhostscript;
//%endclass

// A class for the image created by Ghostscript. 

//%class wxGsImageRefData, wxObjectRefData
//    friend class wxGsImage;
//    friend class wxGhostscript;
//%endclass

%class wxGsImage, wxObject
//    friend class wxGsDll;
//    friend class wxGhostscript;
//    friend class wxGsModule;

    wxGsImage();
    wxGsImage(const wxGsImage& image);

    bool Ok();
    wxString GetName();
    void *GetDevice();
    int GetWidth();
    int GetHeight();
    int GetRowStride();
    int GetBytesPerPixel();
    unsigned int GetRedShift();
    unsigned int GetGreenShift();
    unsigned int GetBlueShift();
    wxGhostscript::ImageType GetImageType();
    unsigned char *GetImageData();
    void ReleaseImageData();
    bool IsLocked();

    wxImage CaptureToImage(wxCoord x, wxCoord y, wxCoord width, wxCoord height);
    wxImage CaptureToImage(wxRect r);
    wxBitmap CaptureToBitmap(wxCoord x, wxCoord y, wxCoord width, wxCoord height);
    wxBitmap CaptureToBitmap(wxRect r);
    void CopyOnto(const wxDC& dc, wxCoord xdest, wxCoord ydest, wxCoord width, wxCoord height, wxCoord xsrc, wxCoord ysrc);
    void CopyOnto(const wxDC& dc, wxRect dest, wxPoint src);
    void CopyOnto(const wxDC& dc, wxRect dest);
    wxColour GetPixel(wxCoord x, wxCoord y);
    wxColour GetPixel(wxPoint p);

    %operator  wxGsImage& operator=(const wxGsImage& image);

    %operator bool operator==(const wxGsImage& image);
    %operator bool operator!=(const wxGsImage& image);
    
%define_object wxNullGsImage
    
%endclass

// A scrolled window class to view the image in. This centres the image if the window is
// wider than the image, and the area outside the image defaults to the system background.

%define_string wxGsWindowDefaultName  wxT("ghostscriptWindow");

%class wxGsWindow, wxScrolledWindow

    wxGsWindow();
    wxGsWindow(wxWindow* parent, wxWindowID id = -1, const wxPoint& pos = wxDefaultPosition, const wxSize& size = wxDefaultSize, long style = wxHSCROLL | wxVSCROLL, const wxString& name =  wxGsWindowDefaultName);

    void SetGsImage(const wxGsImage& image);
    
//    void RefreshRect(const wxRect& rect);
//    void OnDraw(wxDC& dc);

%endclass

%class wxGsWindowX, wxWindow

    wxGsWindowX();
    wxGsWindowX(wxWindow* parent, wxWindowID id = -1, const wxPoint& pos = wxDefaultPosition, const wxSize& size = wxDefaultSize, long style = 0, const wxString& name =  wxGsWindowDefaultName);

    void SetGsImage(const wxGsImage& image);
    
//    void OnPaint(wxPaintEvent& event);

%endclass

